ZookeeperZnodeSpec

Struct ZookeeperZnodeSpec 

pub struct ZookeeperZnodeSpec {
    pub cluster_ref: Option<ZookeeperZnodeClusterRef>,
    pub object_overrides: Option<Vec<BTreeMap<String, Value>>>,
}
A claim for a single ZooKeeper ZNode tree (filesystem node).

A ConfigMap will automatically be created with the same name, containing the connection string in the field ZOOKEEPER. Each ZookeeperZnode gets an isolated ZNode chroot, which the ZOOKEEPER automatically contains. All data inside of this chroot will be deleted when the corresponding ZookeeperZnode is.

ZookeeperZnode is not designed to manage the contents of this ZNode. Instead, it should be used to create a chroot for an installation of an application to work inside. Initializing the contents is the responsibility of the application.

You can learn more about this in the [Isolating clients with ZNodes usage guide](https://docs.stackable.tech/home/nightly/zookeeper/usage_guide/isolating_clients_with_znodes).

Fields

cluster_ref: Option<ZookeeperZnodeClusterRef>

The reference to the ZookeeperCluster that this ZNode belongs to.

object_overrides: Option<Vec<BTreeMap<String, Value>>>

A list of generic Kubernetes objects, which are merged into the objects that the operator creates.

List entries are arbitrary YAML objects, which need to be valid Kubernetes objects.

Read the [Object overrides documentation](https://docs.stackable.tech/home/nightly/concepts/overrides#object-overrides) for more information.